# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_batch.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61ws/aws_batch.proto\x12\x15oak9.tython.aws.batch\x1a\x13shared/shared.proto\"\xb3\x01\n-ComputeEnvironmentLaunchTemplateSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14launch_template_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x1a\n\x12launch_template_id\x18\x04 \x01(\t\"\xe8\x04\n\"ComputeEnvironmentComputeResources\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13spot_iam_fleet_role\x18\x02 \x01(\t\x12\x11\n\tmaxv_cpus\x18\x03 \x01(\x05\x12\x16\n\x0e\x62id_percentage\x18\x04 \x01(\x05\x12\x1a\n\x12security_group_ids\x18\x05 \x03(\t\x12\x0f\n\x07subnets\x18\x06 \x03(\t\x12\x1b\n\x13\x61llocation_strategy\x18\x07 \x01(\t\x12\x11\n\tminv_cpus\x18\x08 \x01(\x05\x12]\n\x0flaunch_template\x18\t \x01(\x0b\x32\x44.oak9.tython.aws.batch.ComputeEnvironmentLaunchTemplateSpecification\x12\x10\n\x08image_id\x18\n \x01(\t\x12\x15\n\rinstance_role\x18\x0b \x01(\t\x12\x16\n\x0einstance_types\x18\x0c \x03(\t\x12\x14\n\x0c\x65\x63\x32_key_pair\x18\r \x01(\t\x12\x17\n\x0fplacement_group\x18\x0e \x01(\t\x12Q\n\x04tags\x18\x0f \x03(\x0b\x32\x43.oak9.tython.aws.batch.ComputeEnvironmentComputeResources.TagsEntry\x12\x15\n\rdesiredv_cpus\x18\x10 \x01(\x05\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf8\x01\n\x12\x43omputeEnvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x14\n\x0cservice_role\x18\x03 \x01(\t\x12 \n\x18\x63ompute_environment_name\x18\x04 \x01(\t\x12T\n\x11\x63ompute_resources\x18\x05 \x01(\x0b\x32\x39.oak9.tython.aws.batch.ComputeEnvironmentComputeResources\x12\r\n\x05state\x18\x06 \x01(\t\"\xc1\x01\n\x05\x42\x61tch\x12\x46\n\x13\x63ompute_environment\x18\x01 \x03(\x0b\x32).oak9.tython.aws.batch.ComputeEnvironment\x12<\n\x0ejob_definition\x18\x02 \x03(\x0b\x32$.oak9.tython.aws.batch.JobDefinition\x12\x32\n\tjob_queue\x18\x03 \x03(\x0b\x32\x1f.oak9.tython.aws.batch.JobQueue\"p\n\x13JobDefinitionSecret\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nvalue_from\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x8a\x01\n\x12JobDefinitionTmpfs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04size\x18\x02 \x01(\x05\x12\x16\n\x0e\x63ontainer_path\x18\x03 \x01(\t\x12\x15\n\rmount_options\x18\x04 \x03(\t\"\x8e\x01\n\x13JobDefinitionDevice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\thost_path\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x03(\t\x12\x16\n\x0e\x63ontainer_path\x18\x04 \x01(\t\"\xae\x02\n\x1cJobDefinitionLinuxParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nswappiness\x18\x02 \x01(\x05\x12\x38\n\x05tmpfs\x18\x03 \x03(\x0b\x32).oak9.tython.aws.batch.JobDefinitionTmpfs\x12\x1a\n\x12shared_memory_size\x18\x04 \x01(\x05\x12;\n\x07\x64\x65vices\x18\x05 \x03(\x0b\x32*.oak9.tython.aws.batch.JobDefinitionDevice\x12\x1c\n\x14init_process_enabled\x18\x06 \x01(\x08\x12\x10\n\x08max_swap\x18\x07 \x01(\x05\"j\n JobDefinitionResourceRequirement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\"\xb4\x02\n\x1dJobDefinitionLogConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x42\n\x0esecret_options\x18\x02 \x03(\x0b\x32*.oak9.tython.aws.batch.JobDefinitionSecret\x12R\n\x07options\x18\x03 \x03(\x0b\x32\x41.oak9.tython.aws.batch.JobDefinitionLogConfiguration.OptionsEntry\x12\x12\n\nlog_driver\x18\x04 \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x95\x01\n\x18JobDefinitionMountPoints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tread_only\x18\x02 \x01(\x08\x12\x15\n\rsource_volume\x18\x03 \x01(\t\x12\x16\n\x0e\x63ontainer_path\x18\x04 \x01(\t\"h\n\x18JobDefinitionVolumesHost\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\"\x9c\x01\n\x14JobDefinitionVolumes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x04host\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.batch.JobDefinitionVolumesHost\x12\x0c\n\x04name\x18\x03 \x01(\t\"p\n\x18JobDefinitionEnvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x84\x01\n\x13JobDefinitionUlimit\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nsoft_limit\x18\x02 \x01(\x05\x12\x12\n\nhard_limit\x18\x03 \x01(\x05\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xe4\x06\n JobDefinitionContainerProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04user\x18\x02 \x01(\t\x12;\n\x07secrets\x18\x03 \x03(\x0b\x32*.oak9.tython.aws.batch.JobDefinitionSecret\x12\x0e\n\x06memory\x18\x04 \x01(\x05\x12\x12\n\nprivileged\x18\x05 \x01(\x08\x12M\n\x10linux_parameters\x18\x06 \x01(\x0b\x32\x33.oak9.tython.aws.batch.JobDefinitionLinuxParameters\x12\x14\n\x0cjob_role_arn\x18\x07 \x01(\t\x12 \n\x18readonly_root_filesystem\x18\x08 \x01(\x08\x12\r\n\x05vcpus\x18\t \x01(\x05\x12\r\n\x05image\x18\n \x01(\t\x12V\n\x15resource_requirements\x18\x0b \x03(\x0b\x32\x37.oak9.tython.aws.batch.JobDefinitionResourceRequirement\x12O\n\x11log_configuration\x18\x0c \x01(\x0b\x32\x34.oak9.tython.aws.batch.JobDefinitionLogConfiguration\x12\x45\n\x0cmount_points\x18\r \x03(\x0b\x32/.oak9.tython.aws.batch.JobDefinitionMountPoints\x12\x1a\n\x12\x65xecution_role_arn\x18\x0e \x01(\t\x12<\n\x07volumes\x18\x0f \x03(\x0b\x32+.oak9.tython.aws.batch.JobDefinitionVolumes\x12\x0f\n\x07\x63ommand\x18\x10 \x03(\t\x12\x44\n\x0b\x65nvironment\x18\x11 \x03(\x0b\x32/.oak9.tython.aws.batch.JobDefinitionEnvironment\x12;\n\x07ulimits\x18\x12 \x03(\x0b\x32*.oak9.tython.aws.batch.JobDefinitionUlimit\x12\x15\n\rinstance_type\x18\x13 \x01(\t\"\xbb\x01\n\x1eJobDefinitionNodeRangeProperty\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\tcontainer\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.batch.JobDefinitionContainerProperties\x12\x14\n\x0ctarget_nodes\x18\x03 \x01(\t\"\xd2\x01\n\x1bJobDefinitionNodeProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tmain_node\x18\x02 \x01(\x05\x12T\n\x15node_range_properties\x18\x03 \x03(\x0b\x32\x35.oak9.tython.aws.batch.JobDefinitionNodeRangeProperty\x12\x11\n\tnum_nodes\x18\x04 \x01(\x05\"q\n\x14JobDefinitionTimeout\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12 \n\x18\x61ttempt_duration_seconds\x18\x02 \x01(\x05\"g\n\x1aJobDefinitionRetryStrategy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x61ttempts\x18\x02 \x01(\x05\"\x9d\x04\n\rJobDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12H\n\nparameters\x18\x03 \x03(\x0b\x32\x34.oak9.tython.aws.batch.JobDefinition.ParametersEntry\x12K\n\x0fnode_properties\x18\x04 \x01(\x0b\x32\x32.oak9.tython.aws.batch.JobDefinitionNodeProperties\x12<\n\x07timeout\x18\x05 \x01(\x0b\x32+.oak9.tython.aws.batch.JobDefinitionTimeout\x12U\n\x14\x63ontainer_properties\x18\x06 \x01(\x0b\x32\x37.oak9.tython.aws.batch.JobDefinitionContainerProperties\x12\x1b\n\x13job_definition_name\x18\x07 \x01(\t\x12I\n\x0eretry_strategy\x18\x08 \x01(\x0b\x32\x31.oak9.tython.aws.batch.JobDefinitionRetryStrategy\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x1fJobQueueComputeEnvironmentOrder\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63ompute_environment\x18\x02 \x01(\t\x12\r\n\x05order\x18\x03 \x01(\x05\"\xd7\x01\n\x08JobQueue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x19\x63ompute_environment_order\x18\x02 \x03(\x0b\x32\x36.oak9.tython.aws.batch.JobQueueComputeEnvironmentOrder\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12\r\n\x05state\x18\x04 \x01(\t\x12\x16\n\x0ejob_queue_name\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_batch_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEENVIRONMENTCOMPUTERESOURCES_TAGSENTRY._options = None
  _COMPUTEENVIRONMENTCOMPUTERESOURCES_TAGSENTRY._serialized_options = b'8\001'
  _JOBDEFINITIONLOGCONFIGURATION_OPTIONSENTRY._options = None
  _JOBDEFINITIONLOGCONFIGURATION_OPTIONSENTRY._serialized_options = b'8\001'
  _JOBDEFINITION_PARAMETERSENTRY._options = None
  _JOBDEFINITION_PARAMETERSENTRY._serialized_options = b'8\001'
  _COMPUTEENVIRONMENTLAUNCHTEMPLATESPECIFICATION._serialized_start=68
  _COMPUTEENVIRONMENTLAUNCHTEMPLATESPECIFICATION._serialized_end=247
  _COMPUTEENVIRONMENTCOMPUTERESOURCES._serialized_start=250
  _COMPUTEENVIRONMENTCOMPUTERESOURCES._serialized_end=866
  _COMPUTEENVIRONMENTCOMPUTERESOURCES_TAGSENTRY._serialized_start=823
  _COMPUTEENVIRONMENTCOMPUTERESOURCES_TAGSENTRY._serialized_end=866
  _COMPUTEENVIRONMENT._serialized_start=869
  _COMPUTEENVIRONMENT._serialized_end=1117
  _BATCH._serialized_start=1120
  _BATCH._serialized_end=1313
  _JOBDEFINITIONSECRET._serialized_start=1315
  _JOBDEFINITIONSECRET._serialized_end=1427
  _JOBDEFINITIONTMPFS._serialized_start=1430
  _JOBDEFINITIONTMPFS._serialized_end=1568
  _JOBDEFINITIONDEVICE._serialized_start=1571
  _JOBDEFINITIONDEVICE._serialized_end=1713
  _JOBDEFINITIONLINUXPARAMETERS._serialized_start=1716
  _JOBDEFINITIONLINUXPARAMETERS._serialized_end=2018
  _JOBDEFINITIONRESOURCEREQUIREMENT._serialized_start=2020
  _JOBDEFINITIONRESOURCEREQUIREMENT._serialized_end=2126
  _JOBDEFINITIONLOGCONFIGURATION._serialized_start=2129
  _JOBDEFINITIONLOGCONFIGURATION._serialized_end=2437
  _JOBDEFINITIONLOGCONFIGURATION_OPTIONSENTRY._serialized_start=2391
  _JOBDEFINITIONLOGCONFIGURATION_OPTIONSENTRY._serialized_end=2437
  _JOBDEFINITIONMOUNTPOINTS._serialized_start=2440
  _JOBDEFINITIONMOUNTPOINTS._serialized_end=2589
  _JOBDEFINITIONVOLUMESHOST._serialized_start=2591
  _JOBDEFINITIONVOLUMESHOST._serialized_end=2695
  _JOBDEFINITIONVOLUMES._serialized_start=2698
  _JOBDEFINITIONVOLUMES._serialized_end=2854
  _JOBDEFINITIONENVIRONMENT._serialized_start=2856
  _JOBDEFINITIONENVIRONMENT._serialized_end=2968
  _JOBDEFINITIONULIMIT._serialized_start=2971
  _JOBDEFINITIONULIMIT._serialized_end=3103
  _JOBDEFINITIONCONTAINERPROPERTIES._serialized_start=3106
  _JOBDEFINITIONCONTAINERPROPERTIES._serialized_end=3974
  _JOBDEFINITIONNODERANGEPROPERTY._serialized_start=3977
  _JOBDEFINITIONNODERANGEPROPERTY._serialized_end=4164
  _JOBDEFINITIONNODEPROPERTIES._serialized_start=4167
  _JOBDEFINITIONNODEPROPERTIES._serialized_end=4377
  _JOBDEFINITIONTIMEOUT._serialized_start=4379
  _JOBDEFINITIONTIMEOUT._serialized_end=4492
  _JOBDEFINITIONRETRYSTRATEGY._serialized_start=4494
  _JOBDEFINITIONRETRYSTRATEGY._serialized_end=4597
  _JOBDEFINITION._serialized_start=4600
  _JOBDEFINITION._serialized_end=5141
  _JOBDEFINITION_PARAMETERSENTRY._serialized_start=5092
  _JOBDEFINITION_PARAMETERSENTRY._serialized_end=5141
  _JOBQUEUECOMPUTEENVIRONMENTORDER._serialized_start=5144
  _JOBQUEUECOMPUTEENVIRONMENTORDER._serialized_end=5278
  _JOBQUEUE._serialized_start=5281
  _JOBQUEUE._serialized_end=5496
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DetectorCFNS3LogsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enable: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enable: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable", "resource_info", b"resource_info"]) -> None: ...

global___DetectorCFNS3LogsConfiguration = DetectorCFNS3LogsConfiguration

@typing_extensions.final
class DetectorCFNDataSourceConfigurations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_LOGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def s3_logs(self) -> global___DetectorCFNS3LogsConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_logs: global___DetectorCFNS3LogsConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_logs", b"s3_logs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_logs", b"s3_logs"]) -> None: ...

global___DetectorCFNDataSourceConfigurations = DetectorCFNDataSourceConfigurations

@typing_extensions.final
class Detector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FINDING_PUBLISHING_FREQUENCY_FIELD_NUMBER: builtins.int
    DATA_SOURCES_FIELD_NUMBER: builtins.int
    ENABLE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    finding_publishing_frequency: builtins.str
    @property
    def data_sources(self) -> global___DetectorCFNDataSourceConfigurations: ...
    enable: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        finding_publishing_frequency: builtins.str = ...,
        data_sources: global___DetectorCFNDataSourceConfigurations | None = ...,
        enable: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_sources", b"data_sources", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_sources", b"data_sources", "enable", b"enable", "finding_publishing_frequency", b"finding_publishing_frequency", "resource_info", b"resource_info"]) -> None: ...

global___Detector = Detector

@typing_extensions.final
class GuardDuty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DETECTOR_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    IP_SET_FIELD_NUMBER: builtins.int
    MASTER_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    THREAT_INTEL_SET_FIELD_NUMBER: builtins.int
    @property
    def detector(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Detector]: ...
    @property
    def filter(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Filter]: ...
    @property
    def ip_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IPSet]: ...
    @property
    def master(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Master]: ...
    @property
    def member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Member]: ...
    @property
    def threat_intel_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreatIntelSet]: ...
    def __init__(
        self,
        *,
        detector: collections.abc.Iterable[global___Detector] | None = ...,
        filter: collections.abc.Iterable[global___Filter] | None = ...,
        ip_set: collections.abc.Iterable[global___IPSet] | None = ...,
        master: collections.abc.Iterable[global___Master] | None = ...,
        member: collections.abc.Iterable[global___Member] | None = ...,
        threat_intel_set: collections.abc.Iterable[global___ThreatIntelSet] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["detector", b"detector", "filter", b"filter", "ip_set", b"ip_set", "master", b"master", "member", b"member", "threat_intel_set", b"threat_intel_set"]) -> None: ...

global___GuardDuty = GuardDuty

@typing_extensions.final
class FilterCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LT_FIELD_NUMBER: builtins.int
    GTE_FIELD_NUMBER: builtins.int
    NEQ_FIELD_NUMBER: builtins.int
    EQ_FIELD_NUMBER: builtins.int
    LTE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    lt: builtins.int
    gte: builtins.int
    @property
    def neq(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def eq(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    lte: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        lt: builtins.int = ...,
        gte: builtins.int = ...,
        neq: collections.abc.Iterable[builtins.str] | None = ...,
        eq: collections.abc.Iterable[builtins.str] | None = ...,
        lte: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["eq", b"eq", "gte", b"gte", "lt", b"lt", "lte", b"lte", "neq", b"neq", "resource_info", b"resource_info"]) -> None: ...

global___FilterCondition = FilterCondition

@typing_extensions.final
class FilterFindingCriteria(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CriterionEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CRITERION_FIELD_NUMBER: builtins.int
    ITEM_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def criterion(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def item_type(self) -> global___FilterCondition: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        criterion: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        item_type: global___FilterCondition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item_type", b"item_type", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["criterion", b"criterion", "item_type", b"item_type", "resource_info", b"resource_info"]) -> None: ...

global___FilterFindingCriteria = FilterFindingCriteria

@typing_extensions.final
class Filter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DETECTOR_ID_FIELD_NUMBER: builtins.int
    FINDING_CRITERIA_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    action: builtins.str
    description: builtins.str
    detector_id: builtins.str
    @property
    def finding_criteria(self) -> global___FilterFindingCriteria: ...
    rank: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        action: builtins.str = ...,
        description: builtins.str = ...,
        detector_id: builtins.str = ...,
        finding_criteria: global___FilterFindingCriteria | None = ...,
        rank: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["finding_criteria", b"finding_criteria", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "description", b"description", "detector_id", b"detector_id", "finding_criteria", b"finding_criteria", "name", b"name", "rank", b"rank", "resource_info", b"resource_info"]) -> None: ...

global___Filter = Filter

@typing_extensions.final
class IPSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    ACTIVATE_FIELD_NUMBER: builtins.int
    DETECTOR_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    format: builtins.str
    activate: builtins.bool
    detector_id: builtins.str
    name: builtins.str
    location: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        format: builtins.str = ...,
        activate: builtins.bool = ...,
        detector_id: builtins.str = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activate", b"activate", "detector_id", b"detector_id", "format", b"format", "location", b"location", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___IPSet = IPSet

@typing_extensions.final
class Master(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DETECTOR_ID_FIELD_NUMBER: builtins.int
    MASTER_ID_FIELD_NUMBER: builtins.int
    INVITATION_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    detector_id: builtins.str
    master_id: builtins.str
    invitation_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        detector_id: builtins.str = ...,
        master_id: builtins.str = ...,
        invitation_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["detector_id", b"detector_id", "invitation_id", b"invitation_id", "master_id", b"master_id", "resource_info", b"resource_info"]) -> None: ...

global___Master = Master

@typing_extensions.final
class Member(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MEMBER_ID_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    DISABLE_EMAIL_NOTIFICATION_FIELD_NUMBER: builtins.int
    DETECTOR_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    status: builtins.str
    member_id: builtins.str
    email: builtins.str
    message: builtins.str
    disable_email_notification: builtins.bool
    detector_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        status: builtins.str = ...,
        member_id: builtins.str = ...,
        email: builtins.str = ...,
        message: builtins.str = ...,
        disable_email_notification: builtins.bool = ...,
        detector_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["detector_id", b"detector_id", "disable_email_notification", b"disable_email_notification", "email", b"email", "member_id", b"member_id", "message", b"message", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___Member = Member

@typing_extensions.final
class ThreatIntelSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    ACTIVATE_FIELD_NUMBER: builtins.int
    DETECTOR_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    format: builtins.str
    activate: builtins.bool
    detector_id: builtins.str
    name: builtins.str
    location: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        format: builtins.str = ...,
        activate: builtins.bool = ...,
        detector_id: builtins.str = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activate", b"activate", "detector_id", b"detector_id", "format", b"format", "location", b"location", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ThreatIntelSet = ThreatIntelSet



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_kms_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleKms(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_CRYPTO_KEY_FIELD_NUMBER: builtins.int
    KMS_CRYPTO_KEY_IAM_BINDING_FIELD_NUMBER: builtins.int
    KMS_CRYPTO_KEY_IAM_MEMBER_FIELD_NUMBER: builtins.int
    KMS_CRYPTO_KEY_IAM_POLICY_FIELD_NUMBER: builtins.int
    KMS_KEY_RING_FIELD_NUMBER: builtins.int
    KMS_KEY_RING_IAM_BINDING_FIELD_NUMBER: builtins.int
    KMS_KEY_RING_IAM_MEMBER_FIELD_NUMBER: builtins.int
    KMS_KEY_RING_IAM_POLICY_FIELD_NUMBER: builtins.int
    KMS_KEY_RING_IMPORT_JOB_FIELD_NUMBER: builtins.int
    KMS_SECRET_CIPHERTEXT_FIELD_NUMBER: builtins.int
    @property
    def kms_crypto_key(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsCryptoKey]: ...
    @property
    def kms_crypto_key_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsCryptoKeyIamBinding]: ...
    @property
    def kms_crypto_key_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsCryptoKeyIamMember]: ...
    @property
    def kms_crypto_key_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsCryptoKeyIamPolicy]: ...
    @property
    def kms_key_ring(self) -> gcp.gcp_kms_pb2.KmsKeyRing: ...
    @property
    def kms_key_ring_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsKeyRingIamBinding]: ...
    @property
    def kms_key_ring_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsKeyRingIamMember]: ...
    @property
    def kms_key_ring_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsKeyRingIamPolicy]: ...
    @property
    def kms_key_ring_import_job(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_kms_pb2.KmsKeyRingImportJob]: ...
    @property
    def kms_secret_ciphertext(self) -> gcp.gcp_kms_pb2.KmsSecretCiphertext: ...
    def __init__(
        self,
        *,
        kms_crypto_key: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsCryptoKey] | None = ...,
        kms_crypto_key_iam_binding: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsCryptoKeyIamBinding] | None = ...,
        kms_crypto_key_iam_member: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsCryptoKeyIamMember] | None = ...,
        kms_crypto_key_iam_policy: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsCryptoKeyIamPolicy] | None = ...,
        kms_key_ring: gcp.gcp_kms_pb2.KmsKeyRing | None = ...,
        kms_key_ring_iam_binding: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsKeyRingIamBinding] | None = ...,
        kms_key_ring_iam_member: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsKeyRingIamMember] | None = ...,
        kms_key_ring_iam_policy: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsKeyRingIamPolicy] | None = ...,
        kms_key_ring_import_job: collections.abc.Iterable[gcp.gcp_kms_pb2.KmsKeyRingImportJob] | None = ...,
        kms_secret_ciphertext: gcp.gcp_kms_pb2.KmsSecretCiphertext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kms_key_ring", b"kms_key_ring", "kms_secret_ciphertext", b"kms_secret_ciphertext"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_crypto_key", b"kms_crypto_key", "kms_crypto_key_iam_binding", b"kms_crypto_key_iam_binding", "kms_crypto_key_iam_member", b"kms_crypto_key_iam_member", "kms_crypto_key_iam_policy", b"kms_crypto_key_iam_policy", "kms_key_ring", b"kms_key_ring", "kms_key_ring_iam_binding", b"kms_key_ring_iam_binding", "kms_key_ring_iam_member", b"kms_key_ring_iam_member", "kms_key_ring_iam_policy", b"kms_key_ring_iam_policy", "kms_key_ring_import_job", b"kms_key_ring_import_job", "kms_secret_ciphertext", b"kms_secret_ciphertext"]) -> None: ...

global___GoogleKms = GoogleKms



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_kms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_kms.proto\x12\x13oak9.tython.aws.kms\x1a\x13shared/shared.proto\"k\n\x05\x41lias\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nalias_name\x18\x02 \x01(\t\x12\x15\n\rtarget_key_id\x18\x03 \x01(\t\"\xc1\x01\n\x03KMS\x12)\n\x05\x61lias\x18\x01 \x03(\x0b\x32\x1a.oak9.tython.aws.kms.Alias\x12%\n\x03key\x18\x02 \x01(\x0b\x32\x18.oak9.tython.aws.kms.Key\x12=\n\x10\x63ustom_key_store\x18\x03 \x01(\x0b\x32#.oak9.tython.aws.kms.CustomKeyStore\x12)\n\x05grant\x18\x04 \x03(\x0b\x32\x1a.oak9.tython.aws.kms.Grant\"\x8b\x01\n\x0e\x43ustomKeyStore\x12\x1c\n\x14\x63loud_hsm_cluster_id\x18\x01 \x01(\t\x12\x1d\n\x15\x63ustom_key_store_name\x18\x02 \x01(\t\x12\x1a\n\x12key_store_password\x18\x03 \x01(\t\x12 \n\x18trust_anchor_certificate\x18\x04 \x01(\t\"\xfc\x01\n\x05Grant\x12\x19\n\x11grantee_principal\x18\x01 \x01(\t\x12\x1a\n\x12retiring_principal\x18\x02 \x01(\t\x12\x14\n\x0cgrant_tokens\x18\x03 \x03(\t\x12\x0e\n\x06key_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x12\n\noperations\x18\x06 \x03(\t\x12@\n\x0b\x63onstraints\x18\x07 \x03(\x0b\x32+.oak9.tython.aws.kms.Grant.ConstraintsEntry\x1a\x32\n\x10\x43onstraintsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x03\n\x03Key\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x1b\n\x13\x65nable_key_rotation\x18\x04 \x01(\x08\x12\x11\n\tkey_usage\x18\x05 \x01(\t\x12\x1e\n\x16pending_window_in_days\x18\x06 \x01(\x05\x12\x30\n\x04tags\x18\x07 \x03(\x0b\x32\".oak9.tython.aws.kms.Key.TagsEntry\x12\x1b\n\x13\x63ustom_key_store_id\x18\x08 \x01(\t\x12*\n\"bypass_policy_lockout_safety_check\x18\t \x01(\x08\x12\x10\n\x08key_spec\x18\n \x01(\t\x12\x14\n\x0cmulti_region\x18\x0b \x01(\x08\x12\x0e\n\x06origin\x18\x0c \x01(\t\x12\x12\n\nkey_policy\x18\r \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_kms_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GRANT_CONSTRAINTSENTRY._options = None
  _GRANT_CONSTRAINTSENTRY._serialized_options = b'8\001'
  _KEY_TAGSENTRY._options = None
  _KEY_TAGSENTRY._serialized_options = b'8\001'
  _ALIAS._serialized_start=63
  _ALIAS._serialized_end=170
  _KMS._serialized_start=173
  _KMS._serialized_end=366
  _CUSTOMKEYSTORE._serialized_start=369
  _CUSTOMKEYSTORE._serialized_end=508
  _GRANT._serialized_start=511
  _GRANT._serialized_end=763
  _GRANT_CONSTRAINTSENTRY._serialized_start=713
  _GRANT_CONSTRAINTSENTRY._serialized_end=763
  _KEY._serialized_start=766
  _KEY._serialized_end=1190
  _KEY_TAGSENTRY._serialized_start=1147
  _KEY_TAGSENTRY._serialized_end=1190
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_rds_dbcluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61ws/aws_rds_dbcluster.proto\x12\x1doak9.tython.aws.rds_dbcluster\x1a\x13shared/shared.proto\"y\n\x16\x44\x42\x43lusterDBClusterRole\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\xba\x01\n\x1d\x44\x42\x43lusterScalingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nauto_pause\x18\x02 \x01(\x08\x12\x14\n\x0cmax_capacity\x18\x03 \x01(\x05\x12\x14\n\x0cmin_capacity\x18\x04 \x01(\x05\x12 \n\x18seconds_until_auto_pause\x18\x05 \x01(\x05\"\x97\t\n\tDBCluster\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x10\x61ssociated_roles\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.rds_dbcluster.DBClusterDBClusterRole\x12\x1a\n\x12\x61vailability_zones\x18\x03 \x03(\t\x12\x18\n\x10\x62\x61\x63ktrack_window\x18\x04 \x01(\x05\x12\x1f\n\x17\x62\x61\x63kup_retention_period\x18\x05 \x01(\x05\x12\x1d\n\x15\x64\x62_cluster_identifier\x18\x06 \x01(\t\x12\'\n\x1f\x64\x62_cluster_parameter_group_name\x18\x07 \x01(\t\x12\x1c\n\x14\x64\x62_subnet_group_name\x18\x08 \x01(\t\x12\x15\n\rdatabase_name\x18\t \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x12&\n\x1e\x65nable_cloudwatch_logs_exports\x18\x0b \x03(\t\x12\x1c\n\x14\x65nable_http_endpoint\x18\x0c \x01(\x08\x12*\n\"enable_iam_database_authentication\x18\r \x01(\x08\x12\x0e\n\x06\x65ngine\x18\x0e \x01(\t\x12\x13\n\x0b\x65ngine_mode\x18\x0f \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x10 \x01(\t\x12\x12\n\nkms_key_id\x18\x11 \x01(\t\x12\x1c\n\x14master_user_password\x18\x12 \x01(\t\x12\x17\n\x0fmaster_username\x18\x13 \x01(\t\x12\x0c\n\x04port\x18\x14 \x01(\x05\x12\x1f\n\x17preferred_backup_window\x18\x15 \x01(\t\x12$\n\x1cpreferred_maintenance_window\x18\x16 \x01(\t\x12%\n\x1dreplication_source_identifier\x18\x17 \x01(\t\x12\x14\n\x0crestore_type\x18\x18 \x01(\t\x12[\n\x15scaling_configuration\x18\x19 \x01(\x0b\x32<.oak9.tython.aws.rds_dbcluster.DBClusterScalingConfiguration\x12\x1b\n\x13snapshot_identifier\x18\x1a \x01(\t\x12$\n\x1csource_db_cluster_identifier\x18\x1b \x01(\t\x12\x15\n\rsource_region\x18\x1c \x01(\t\x12\x19\n\x11storage_encrypted\x18\x1d \x01(\x08\x12@\n\x04tags\x18\x1e \x03(\x0b\x32\x32.oak9.tython.aws.rds_dbcluster.DBCluster.TagsEntry\x12\"\n\x1ause_latest_restorable_time\x18\x1f \x01(\x08\x12\x1e\n\x16vpc_security_group_ids\x18  \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb1\x05\n\rRDS_DBCluster\x12<\n\ndb_cluster\x18\x01 \x01(\x0b\x32(.oak9.tython.aws.rds_dbcluster.DBCluster\x12Z\n\x1a\x64\x62_cluster_parameter_group\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.rds_dbcluster.DBClusterParameterGroup\x12\x38\n\x08\x64\x62_proxy\x18\x03 \x03(\x0b\x32&.oak9.tython.aws.rds_dbcluster.DBProxy\x12P\n\x15\x64\x62_proxy_target_group\x18\x04 \x03(\x0b\x32\x31.oak9.tython.aws.rds_dbcluster.DBProxyTargetGroup\x12I\n\x11\x64\x62_security_group\x18\x05 \x01(\x0b\x32..oak9.tython.aws.rds_dbcluster.DBSecurityGroup\x12X\n\x19\x64\x62_security_group_ingress\x18\x06 \x03(\x0b\x32\x35.oak9.tython.aws.rds_dbcluster.DBSecurityGroupIngress\x12\x45\n\x0f\x64\x62_subnet_group\x18\x07 \x01(\x0b\x32,.oak9.tython.aws.rds_dbcluster.DBSubnetGroup\x12L\n\x12\x65vent_subscription\x18\x08 \x01(\x0b\x32\x30.oak9.tython.aws.rds_dbcluster.EventSubscription\x12@\n\x0coption_group\x18\t \x01(\x0b\x32*.oak9.tython.aws.rds_dbcluster.OptionGroup\"\x83\x03\n\x17\x44\x42\x43lusterParameterGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06\x66\x61mily\x18\x03 \x01(\t\x12Z\n\nparameters\x18\x04 \x03(\x0b\x32\x46.oak9.tython.aws.rds_dbcluster.DBClusterParameterGroup.ParametersEntry\x12N\n\x04tags\x18\x05 \x03(\x0b\x32@.oak9.tython.aws.rds_dbcluster.DBClusterParameterGroup.TagsEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"g\n\x10\x44\x42ProxyTagFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xfc\x02\n\x07\x44\x42Proxy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdb_proxy_name\x18\x02 \x01(\t\x12\x15\n\rdebug_logging\x18\x03 \x01(\x08\x12\x15\n\rengine_family\x18\x04 \x01(\t\x12\x1b\n\x13idle_client_timeout\x18\x05 \x01(\x05\x12\x13\n\x0brequire_tls\x18\x06 \x01(\x08\x12\x10\n\x08role_arn\x18\x07 \x01(\t\x12=\n\x04tags\x18\x08 \x03(\x0b\x32/.oak9.tython.aws.rds_dbcluster.DBProxyTagFormat\x12\x1e\n\x16vpc_security_group_ids\x18\t \x03(\t\x12\x16\n\x0evpc_subnet_ids\x18\n \x03(\t\x12\x38\n\x04\x61uth\x18\x0b \x03(\x0b\x32*.oak9.tython.aws.rds_dbcluster.DBProxyAuth\"\x91\x02\n7DBProxyTargetGroupConnectionPoolConfigurationInfoFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17max_connections_percent\x18\x02 \x01(\x05\x12$\n\x1cmax_idle_connections_percent\x18\x03 \x01(\x05\x12!\n\x19\x63onnection_borrow_timeout\x18\x04 \x01(\x05\x12\x1f\n\x17session_pinning_filters\x18\x05 \x03(\t\x12\x12\n\ninit_query\x18\x06 \x01(\t\"\xc5\x02\n\x12\x44\x42ProxyTargetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdb_proxy_name\x18\x02 \x01(\t\x12\x19\n\x11target_group_name\x18\x03 \x01(\t\x12\x82\x01\n\"connection_pool_configuration_info\x18\x04 \x01(\x0b\x32V.oak9.tython.aws.rds_dbcluster.DBProxyTargetGroupConnectionPoolConfigurationInfoFormat\x12\x1f\n\x17\x64\x62_instance_identifiers\x18\x05 \x03(\t\x12\x1e\n\x16\x64\x62_cluster_identifiers\x18\x06 \x03(\t\"\xca\x01\n\x16\x44\x42SecurityGroupIngress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12\x1e\n\x16\x65_c2_security_group_id\x18\x03 \x01(\t\x12 \n\x18\x65_c2_security_group_name\x18\x04 \x01(\t\x12$\n\x1c\x65_c2_security_group_owner_id\x18\x05 \x01(\t\"\xc9\x02\n\x0f\x44\x42SecurityGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\x19\x64\x62_security_group_ingress\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.rds_dbcluster.DBSecurityGroupIngress\x12\x13\n\x0b\x65_c2_vpc_id\x18\x03 \x01(\t\x12\x19\n\x11group_description\x18\x04 \x01(\t\x12\x46\n\x04tags\x18\x05 \x03(\x0b\x32\x38.oak9.tython.aws.rds_dbcluster.DBSecurityGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x02\n\rDBSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1b\x64\x62_subnet_group_description\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x62_subnet_group_name\x18\x03 \x01(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\t\x12\x44\n\x04tags\x18\x05 \x03(\x0b\x32\x36.oak9.tython.aws.rds_dbcluster.DBSubnetGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb7\x01\n\x11\x45ventSubscription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x18\n\x10\x65vent_categories\x18\x03 \x03(\t\x12\x15\n\rsns_topic_arn\x18\x04 \x01(\t\x12\x12\n\nsource_ids\x18\x05 \x03(\t\x12\x13\n\x0bsource_type\x18\x06 \x01(\t\"p\n\x18OptionGroupOptionSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xb5\x02\n\x1eOptionGroupOptionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1d\x64\x62_security_group_memberships\x18\x02 \x03(\t\x12\x13\n\x0boption_name\x18\x03 \x01(\t\x12P\n\x0foption_settings\x18\x04 \x03(\x0b\x32\x37.oak9.tython.aws.rds_dbcluster.OptionGroupOptionSetting\x12\x16\n\x0eoption_version\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\x05\x12&\n\x1evpc_security_group_memberships\x18\x07 \x03(\t\"\xa9\x01\n\x0b\x44\x42ProxyAuth\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x61uth_scheme\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08iam_auth\x18\x04 \x01(\t\x12\x12\n\nsecret_arn\x18\x05 \x01(\t\x12\x11\n\tuser_name\x18\x06 \x01(\t\"\xea\x02\n\x0bOptionGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x65ngine_name\x18\x02 \x01(\t\x12\x1c\n\x14major_engine_version\x18\x03 \x01(\t\x12\\\n\x15option_configurations\x18\x04 \x03(\x0b\x32=.oak9.tython.aws.rds_dbcluster.OptionGroupOptionConfiguration\x12 \n\x18option_group_description\x18\x05 \x01(\t\x12\x42\n\x04tags\x18\x06 \x03(\x0b\x32\x34.oak9.tython.aws.rds_dbcluster.OptionGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_rds_dbcluster_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DBCLUSTER_TAGSENTRY._options = None
  _DBCLUSTER_TAGSENTRY._serialized_options = b'8\001'
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._options = None
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._serialized_options = b'8\001'
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._options = None
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBSECURITYGROUP_TAGSENTRY._options = None
  _DBSECURITYGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBSUBNETGROUP_TAGSENTRY._options = None
  _DBSUBNETGROUP_TAGSENTRY._serialized_options = b'8\001'
  _OPTIONGROUP_TAGSENTRY._options = None
  _OPTIONGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBCLUSTERDBCLUSTERROLE._serialized_start=83
  _DBCLUSTERDBCLUSTERROLE._serialized_end=204
  _DBCLUSTERSCALINGCONFIGURATION._serialized_start=207
  _DBCLUSTERSCALINGCONFIGURATION._serialized_end=393
  _DBCLUSTER._serialized_start=396
  _DBCLUSTER._serialized_end=1571
  _DBCLUSTER_TAGSENTRY._serialized_start=1528
  _DBCLUSTER_TAGSENTRY._serialized_end=1571
  _RDS_DBCLUSTER._serialized_start=1574
  _RDS_DBCLUSTER._serialized_end=2263
  _DBCLUSTERPARAMETERGROUP._serialized_start=2266
  _DBCLUSTERPARAMETERGROUP._serialized_end=2653
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._serialized_start=2559
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._serialized_end=2608
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._serialized_start=1528
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._serialized_end=1571
  _DBPROXYTAGFORMAT._serialized_start=2655
  _DBPROXYTAGFORMAT._serialized_end=2758
  _DBPROXY._serialized_start=2761
  _DBPROXY._serialized_end=3141
  _DBPROXYTARGETGROUPCONNECTIONPOOLCONFIGURATIONINFOFORMAT._serialized_start=3144
  _DBPROXYTARGETGROUPCONNECTIONPOOLCONFIGURATIONINFOFORMAT._serialized_end=3417
  _DBPROXYTARGETGROUP._serialized_start=3420
  _DBPROXYTARGETGROUP._serialized_end=3745
  _DBSECURITYGROUPINGRESS._serialized_start=3748
  _DBSECURITYGROUPINGRESS._serialized_end=3950
  _DBSECURITYGROUP._serialized_start=3953
  _DBSECURITYGROUP._serialized_end=4282
  _DBSECURITYGROUP_TAGSENTRY._serialized_start=1528
  _DBSECURITYGROUP_TAGSENTRY._serialized_end=1571
  _DBSUBNETGROUP._serialized_start=4285
  _DBSUBNETGROUP._serialized_end=4559
  _DBSUBNETGROUP_TAGSENTRY._serialized_start=1528
  _DBSUBNETGROUP_TAGSENTRY._serialized_end=1571
  _EVENTSUBSCRIPTION._serialized_start=4562
  _EVENTSUBSCRIPTION._serialized_end=4745
  _OPTIONGROUPOPTIONSETTING._serialized_start=4747
  _OPTIONGROUPOPTIONSETTING._serialized_end=4859
  _OPTIONGROUPOPTIONCONFIGURATION._serialized_start=4862
  _OPTIONGROUPOPTIONCONFIGURATION._serialized_end=5171
  _DBPROXYAUTH._serialized_start=5174
  _DBPROXYAUTH._serialized_end=5343
  _OPTIONGROUP._serialized_start=5346
  _OPTIONGROUP._serialized_end=5708
  _OPTIONGROUP_TAGSENTRY._serialized_start=1528
  _OPTIONGROUP_TAGSENTRY._serialized_end=1571
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_iot1click.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_iot1click.proto\x12\x19oak9.tython.aws.iot1click\x1a\x13shared/shared.proto\"e\n\x06\x44\x65vice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"\xff\x01\n\tIoT1Click\x12\x31\n\x06\x64\x65vice\x18\x01 \x03(\x0b\x32!.oak9.tython.aws.iot1click.Device\x12\x37\n\tplacement\x18\x02 \x03(\x0b\x32$.oak9.tython.aws.iot1click.Placement\x12\x33\n\x07project\x18\x03 \x03(\x0b\x32\".oak9.tython.aws.iot1click.Project\x12Q\n\x17project_device_template\x18\x04 \x03(\x0b\x32\x30.oak9.tython.aws.iot1click.ProjectDeviceTemplate\"\x82\x03\n\tPlacement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eplacement_name\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12W\n\x12\x61ssociated_devices\x18\x04 \x03(\x0b\x32;.oak9.tython.aws.iot1click.Placement.AssociatedDevicesEntry\x12H\n\nattributes\x18\x05 \x03(\x0b\x32\x34.oak9.tython.aws.iot1click.Placement.AttributesEntry\x1a\x38\n\x16\x41ssociatedDevicesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x91\x03\n\x18ProjectPlacementTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x10\x64\x65vice_templates\x18\x02 \x03(\x0b\x32H.oak9.tython.aws.iot1click.ProjectPlacementTemplate.DeviceTemplatesEntry\x12\x66\n\x12\x64\x65\x66\x61ult_attributes\x18\x03 \x03(\x0b\x32J.oak9.tython.aws.iot1click.ProjectPlacementTemplate.DefaultAttributesEntry\x1a\x36\n\x14\x44\x65viceTemplatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16\x44\x65\x66\x61ultAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x01\n\x07Project\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12O\n\x12placement_template\x18\x03 \x01(\x0b\x32\x33.oak9.tython.aws.iot1click.ProjectPlacementTemplate\x12\x14\n\x0cproject_name\x18\x04 \x01(\t\"\x84\x02\n\x15ProjectDeviceTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65vice_type\x18\x02 \x01(\t\x12\x63\n\x12\x63\x61llback_overrides\x18\x03 \x03(\x0b\x32G.oak9.tython.aws.iot1click.ProjectDeviceTemplate.CallbackOverridesEntry\x1a\x38\n\x16\x43\x61llbackOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_iot1click_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLACEMENT_ASSOCIATEDDEVICESENTRY._options = None
  _PLACEMENT_ASSOCIATEDDEVICESENTRY._serialized_options = b'8\001'
  _PLACEMENT_ATTRIBUTESENTRY._options = None
  _PLACEMENT_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _PROJECTPLACEMENTTEMPLATE_DEVICETEMPLATESENTRY._options = None
  _PROJECTPLACEMENTTEMPLATE_DEVICETEMPLATESENTRY._serialized_options = b'8\001'
  _PROJECTPLACEMENTTEMPLATE_DEFAULTATTRIBUTESENTRY._options = None
  _PROJECTPLACEMENTTEMPLATE_DEFAULTATTRIBUTESENTRY._serialized_options = b'8\001'
  _PROJECTDEVICETEMPLATE_CALLBACKOVERRIDESENTRY._options = None
  _PROJECTDEVICETEMPLATE_CALLBACKOVERRIDESENTRY._serialized_options = b'8\001'
  _DEVICE._serialized_start=75
  _DEVICE._serialized_end=176
  _IOT1CLICK._serialized_start=179
  _IOT1CLICK._serialized_end=434
  _PLACEMENT._serialized_start=437
  _PLACEMENT._serialized_end=823
  _PLACEMENT_ASSOCIATEDDEVICESENTRY._serialized_start=716
  _PLACEMENT_ASSOCIATEDDEVICESENTRY._serialized_end=772
  _PLACEMENT_ATTRIBUTESENTRY._serialized_start=774
  _PLACEMENT_ATTRIBUTESENTRY._serialized_end=823
  _PROJECTPLACEMENTTEMPLATE._serialized_start=826
  _PROJECTPLACEMENTTEMPLATE._serialized_end=1227
  _PROJECTPLACEMENTTEMPLATE_DEVICETEMPLATESENTRY._serialized_start=1115
  _PROJECTPLACEMENTTEMPLATE_DEVICETEMPLATESENTRY._serialized_end=1169
  _PROJECTPLACEMENTTEMPLATE_DEFAULTATTRIBUTESENTRY._serialized_start=1171
  _PROJECTPLACEMENTTEMPLATE_DEFAULTATTRIBUTESENTRY._serialized_end=1227
  _PROJECT._serialized_start=1230
  _PROJECT._serialized_end=1420
  _PROJECTDEVICETEMPLATE._serialized_start=1423
  _PROJECTDEVICETEMPLATE._serialized_end=1683
  _PROJECTDEVICETEMPLATE_CALLBACKOVERRIDESENTRY._serialized_start=1627
  _PROJECTDEVICETEMPLATE_CALLBACKOVERRIDESENTRY._serialized_end=1683
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_compute_firewall_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleComputeFirewallPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_FIREWALL_POLICY_FIELD_NUMBER: builtins.int
    COMPUTE_FIREWALL_POLICY_ASSOCIATION_FIELD_NUMBER: builtins.int
    COMPUTE_FIREWALL_POLICY_RULE_FIELD_NUMBER: builtins.int
    @property
    def compute_firewall_policy(self) -> gcp.gcp_compute_firewall_pb2.ComputeFirewallPolicy: ...
    @property
    def compute_firewall_policy_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_compute_firewall_pb2.ComputeFirewallPolicyAssociation]: ...
    @property
    def compute_firewall_policy_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_compute_firewall_pb2.ComputeFirewallPolicyRule]: ...
    def __init__(
        self,
        *,
        compute_firewall_policy: gcp.gcp_compute_firewall_pb2.ComputeFirewallPolicy | None = ...,
        compute_firewall_policy_association: collections.abc.Iterable[gcp.gcp_compute_firewall_pb2.ComputeFirewallPolicyAssociation] | None = ...,
        compute_firewall_policy_rule: collections.abc.Iterable[gcp.gcp_compute_firewall_pb2.ComputeFirewallPolicyRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compute_firewall_policy", b"compute_firewall_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_firewall_policy", b"compute_firewall_policy", "compute_firewall_policy_association", b"compute_firewall_policy_association", "compute_firewall_policy_rule", b"compute_firewall_policy_rule"]) -> None: ...

global___GoogleComputeFirewallPolicy = GoogleComputeFirewallPolicy
